==> camunda-engine-7.1.0-alpha2-sources.jar: org/camunda/bpm/engine/impl/util/io/ResourceStreamSource.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.util.io;

import java.io.InputStream;

import org.camunda.bpm.engine.ProcessEngineException;
import org.camunda.bpm.engine.impl.util.ReflectUtil;


/**
 * @author Tom Baeyens
 */
public class ResourceStreamSource implements StreamSource {

  String resource;
  ClassLoader classLoader;
  
  public ResourceStreamSource(String resource) {
    this.resource = resource;
  }

  public ResourceStreamSource(String resource, ClassLoader classLoader) {
    this.resource = resource;
    this.classLoader = classLoader;
  }

  public InputStream getInputStream() {
    InputStream inputStream = null;
    if (classLoader==null) {
      inputStream = ReflectUtil.getResourceAsStream(resource);
    } else {
      classLoader.getResourceAsStream(resource);
    }
    if (inputStream==null) {
      throw new ProcessEngineException("resource '"+resource+"' doesn't exist");
    }
    return inputStream;
  }

  public String toString() {
    return "Resource["+resource+"]";
  }
}

==> camunda-engine-7.11.0-alpha2-sources.jar: org/camunda/bpm/engine/impl/util/io/ResourceStreamSource.java <==
/*
 * Copyright © 2013-2018 camunda services GmbH and various authors (info@camunda.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.util.io;

import java.io.InputStream;
import org.camunda.bpm.engine.impl.util.ReflectUtil;

import static org.camunda.bpm.engine.impl.util.EnsureUtil.ensureNotNull;


/**
 * @author Tom Baeyens
 */
public class ResourceStreamSource implements StreamSource {

  String resource;
  ClassLoader classLoader;
  
  public ResourceStreamSource(String resource) {
    this.resource = resource;
  }

  public ResourceStreamSource(String resource, ClassLoader classLoader) {
    this.resource = resource;
    this.classLoader = classLoader;
  }

  public InputStream getInputStream() {
    InputStream inputStream = null;
    if (classLoader == null) {
      inputStream = ReflectUtil.getResourceAsStream(resource);
    } else {
      classLoader.getResourceAsStream(resource);
    }
    ensureNotNull("resource '" + resource + "' doesn't exist", "inputStream", inputStream);
    return inputStream;
  }

  public String toString() {
    return "Resource["+resource+"]";
  }
}
